<p align="center">
  <img width="420px" src="https://raw.githubusercontent.com/suzukey/majocol/main/docs/img/majocol.png" alt='majocol'>
</p>

<p align="center">
  <em>Pick major colors from image</em>
</p>

<p align="center">
  <a href="https://pypi.org/project/majocol/" target="_blank">
    <img src="https://badge.fury.io/py/majocol.svg" alt="Package version">
  </a>
</p>

---

**Documentation**:

**Demo**:

---

# MajoCol

## Requirements

Python 3.6+

## Installation

```shell
$ pip3 install majocol
```

## Example

```python

```

<p align="center">&mdash; 🪄 &mdash;</p>

<p align="center">
  <i>MajoCol is licensed under the terms of the <a href="https://github.com/suzukey/majocol/blob/main/LICENSE">MIT license</a>.</i>
</p>
